#
# spec file for package snpguest
#
# Copyright (c) 2024 SUSE LLC
# Copyright (C) 2023 VirTEE
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           snpguest
Version:        0.3.2~0
Release:        1.3
Summary:        A Rust command-line tool for interacting with the AMD Secure Processor
License:        Apache-2.0
Group:          Productivity/Security
URL:            https://github.com/virtee/snpguest
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        cargo_config
BuildRequires:  cargo-packaging
ExclusiveArch:  x86_64

%description
snpguest is a command line utility for interacting with the AMD Secure Encrypted Virtualization - Secure Nested Paging (SEV-SNP) guest environment (via the /dev/sev-guest device).

%prep
# The number passed to -a (a stands for "after") should be equivalent to the Source tag number
# of the vendor tarball, 1 in this case (from Source1).
%autosetup -a1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Mon Jan 22 2024 Caleb Crane (caleb.crane@suse.com)
- Update to version 0.3.2~0:
  * crates.io: Updating crates.io for publishing
  * cert: Fixing minor bug with certificates
  * Fixing report request serialization
  * hyperv: Adding feature flag for hyperv
  * VCEK: Patching for x509 error
  * 9: Adding Cargo.lock for dependency tracking
  * 9: Adding Rust Minimum Version
  * Auto Assign: Adding yml files
  * Update docs/snpguest.1.adoc
  * Change false to hv in main
  * Fixing comments on PR, added code to main, and fixed flag ambiguity
  * Adding Derived Key Feature
  * azure: Use mutable variable instead of consistently recreating
  * docs: Document report --platform flag
  * report: Add --platform flag for Hyper-V
  * hyperv: Require VMPL 0 for attestation report
  * hyperv: Check for hypervisor guest + Hyper-V functions
  * hyperv: Fetch attestation report from Azure vTPM
  * hyperv: Detect if in a Hyper-V SEV-SNP guest
  * Reformat with cargo fmt
  * verify: Fix clippy warning
  * Fixing clippy Errors
  * Changed Attestation workflow to always require a bin Attestation Report. Fixed requested changes.
  * Adding new write_cert function. Organizing code.
  * Adding proctype enum
  * Attestation Report requested when used. New fetch command. Continuity fixes.
  * Fixing dependencies
* Mon Jul 10 2023 larry.j.dewey@gmail.com
- Update to version 0.2.2~0:
  * Update to 0.2.2
  * Update Cargo.toml readme field
  * Update to 0.2.1
* Tue Jun  6 2023 larry.j.dewey@gmail.com
- Update to version 0.2.0~0:
  * Fixing dependencies
  * Changed VMPL to use updated SEV library
  * Convert README to Markdown
  * .gitignore: Add Cargo.lock
  * Reformat
  * Made certificate path and proc model required. Changed Cargo.toml. Shortened verify  commands.
  * Restrucuted project. Using updated SEV library. Adressed comments.
  * Changed identification to enum
  * Fixed request module with comments. Now using new virtee library
  * Added verify-TCB, attestation signture verification and quiet flag
* Tue Jun  6 2023 larry.j.dewey@gmail.com
- Update to version 0.2.0~0:
  * Fixing dependencies
  * Changed VMPL to use updated SEV library
  * Convert README to Markdown
  * .gitignore: Add Cargo.lock
  * Reformat
  * Made certificate path and proc model required. Changed Cargo.toml. Shortened verify  commands.
  * Restrucuted project. Using updated SEV library. Adressed comments.
  * Changed identification to enum
  * Fixed request module with comments. Now using new virtee library
  * Added verify-TCB, attestation signture verification and quiet flag
* Tue May 23 2023 Larry Dewey <larry.j.dewey@gmail.com>
- Initial Release v0.2.0
